@@ -32,6 +32,8 @@
  * 18 Sep 01, tuorfa@yahoo.com: added AttrStack (stack of stacks) paradigm
  * 22 Sep 01, tuorfa@yahoo.com: added comment blocks
  * 29 Mar 05, daved@physiol.usyd.edu.au: changes requested by ZT Smith
+ * 16 Dec 07, daved@physiol.usyd.edu.au: fixed fore/background_begin error
+ *                       and updated to GPL v3
  *--------------------------------------------------------------------*/
 
 #ifdef HAVE_CONFIG_H
@@ -134,7 +136,7 @@ attr_express_begin (int attr, char* param) {
 
 	case ATTR_BACKGROUND: 
 		if (!simple_mode)
-		  printf(op->foreground_begin,param); 
+		  printf(op->background_begin,param); 
 		break;
 
 	case ATTR_SUPER: 
