@@ -38,6 +38,8 @@
  * 21 Jul 05, daved@physiol.usyd.edu.au: added endash
  * 19 Aug 05, ax2groin@arbornet.org: added more chars and changes to ANSI
  * 05 Jan 06, marcossamaral@terra.com.br: fixed bugs #14982 and #14983
+ * 13 Dec 07, daved@physiol.usyd.edu.au: fixed some missing entity ';'
+ * 16 Dec 07, daved@physiol.usyd.edu.au: updated to GPL v3
  *--------------------------------------------------------------------*/
 
 #ifdef HAVE_CONFIG_H
@@ -643,8 +645,8 @@ static char* cp437 [] = {
 /* 0x9b */ "&cent;",
 /* 0x9c */ "&pound;",
 /* 0x9d */ "&yen;",
-/* 0x9e */ "&#8359", /* peseta */
-/* 0x9f */ "&#402", /* small f with hook */
+/* 0x9e */ "&#8359;", /* peseta */
+/* 0x9f */ "&#402;", /* small f with hook */
 /* 0xa0 */ "&aacute;",
 /* 0xa1 */ "&iacute;",
 /* 0xa2 */ "&oacute;",
@@ -654,7 +656,7 @@ static char* cp437 [] = {
 /* 0xa6 */ "&ordf;",
 /* 0xa7 */ "&frac14;",
 /* 0xa8 */ "&iquest;",
-/* 0xa9 */ "&#8976", /* reversed not */
+/* 0xa9 */ "&#8976;", /* reversed not */
 /* 0xaa */ "&not;",
 /* 0xab */ "&frac12;",
 /* 0xac */ "&raquo;",
@@ -874,105 +876,106 @@ static char* cp850 [] = {
 /* 0xff */  "&nbsp;",
 };
 #if 1 /* daved - 0.20.3 */
-static char *Greek[] = /* Times New Roman Greek */
+static char *Greek[] =
 {
-/* 0x80 */  "&euro;",
-/* 0x81 */  0,
-/* 0x82 */  "&sbquo;",
-/* 0x83 */  "&fnof;",
-/* 0x84 */  "&bdquo;",
-/* 0x85 */  "&hellip;",
-/* 0x86 */  "&dagger;",
-/* 0x87 */  "&Dagger;",
-/* 0x88 */  "&circ;",
-/* 0x89 */  "&permil;",
-/* 0x8a */  "&Scaron;",
-/* 0x8b */  "&lsaquo;",
-/* 0x8c */  "&OElig;",
-/* 0x8d */  0,	/* RI ? */
-/* 0x8e */  "&#142;",	/* Z caron */
-/* 0x8f */  0,  /* SS3 */
-/* 0x90 */  0,	/* DCS */
-/* 0x91 */  "&lsquo;",
-/* 0x92 */  "&rsquo;",
-/* 0x93 */  "&ldquo;",
-/* 0x94 */  "&rdquo;",
-/* 0x95 */  "&bull;",
-/* 0x96 */  "&ndash;",
-/* 0x97 */  "&mdash;",
-/* 0x98 */  "&tilde;",
-/* 0x99 */  "&trade;",
-/* 0x9a */  "&scaron",
-/* 0x9b */  "&rsaquo;",
-/* 0x9c */  "&oelig;",
-/* 0x9d */  0, /* OSC ?? */
-/* 0x9e */  "&#158;",	/* z caron */
-/* 0x9f */  "&Yuml;",
-/* 0xa0 */  "&nbsp;",
-/* 0xa1 */  "&#901;", /* combined umlaut and acute accent */
-/* 0xa2 */  "&#902;", /* 'A */
-/* 0xa3 */  "&pound;",
-/* 0xa4 */  "&curren;",
-/* 0xa5 */  "&yen;",
-/* 0xa6 */  "&brvbar;",
-/* 0xa7 */  "&sect;",
-/* 0xa8 */  "&uml;",
-/* 0xa9 */  "&copy;",
-/* 0xaa */  "&#63737;", /* top & left rectangle */
-/* 0xab */  "&laquo;",
-/* 0xac */  "&not;",
-/* 0xad */  "&minus;",
-/* 0xae */  "&reg;",
-/* 0xaf */  "&mdash;",
-/* 0xb0 */  "&deg;",
-/* 0xb1 */  "&plusmn;",
-/* 0xb2 */  "&sup2;",
-/* 0xb3 */  "&sup3;",
-/* 0xb4 */  "&acute;",
-/* 0xb5 */  "&micro;",
-/* 0xb6 */  "&para;",
-/* 0xb7 */  "&middot;",
-/* 0xb8 */  "&#904;",  /* 'E */
-/* 0xb9 */  "&#905;", /* 'H */
-/* 0xba */  "&#906;", /* 'I */
-/* 0xbb */  "&raquo;",
-/* 0xbc */  "&#908;", /* 'O */
-/* 0xbd */  "&frac12;",
-/* 0xbe */  "&#910;", /* 'Y */
-/* 0xbf */  "&#911;", /* 'Omega */
-/* 0xc0 */  "&#912;", /* dotless i umlaut acute */
-/* 0xc1 */  "&Alpha;",
-/* 0xc2 */  "&Beta;",
-/* 0xc3 */  "&Gamma;",
-/* 0xc4 */  "&Delta;",
-/* 0xc5 */  "&Epsilon;",
-/* 0xc6 */  "&Zeta;",
-/* 0xc7 */  "&Eta;",
-/* 0xc8 */  "&Theta;",
-/* 0xc9 */  "&Iota;",
-/* 0xca */  "&Kappa;",
-/* 0xcb */  "&Lambda;",
-/* 0xcc */  "&Mu;",
-/* 0xcd */  "&Nu;",
-/* 0xce */  "&Xi;",
-/* 0xcf */  "&Omicron;",
-/* 0xd0 */  "&Pi;",
-/* 0xd1 */  "&Rho;",
-/* 0xd2 */  "&#63738;", /* long vertical bar */
-/* 0xd3 */  "&Sigma;",
-/* 0xd4 */  "&Tau;",
-/* 0xd5 */  "&Upsilon;",
-/* 0xd6 */  "&Phi;",
-/* 0xd7 */  "&Chi;",
-/* 0xd8 */  "&Psi;",
-/* 0xd9 */  "&Omega;",
-/* 0xda */  "&#938;", /* Iota umlaut */
-/* 0xdb */  "&#939;", /* Upsilon umlaut */
-/* 0xdc */  "&#940;", /* alpha acute */
-/* 0xdd */  "&#941;", /* epsilon acute */
-/* 0xde */  "&#942;", /* eta acute */
-/* 0xdf */  "&#943;", /* iota acute */
-/* 0xe0 */  "&#944;", /* nu umlaut acute */
+/* 0x80 */  "&ccedil;",
+/* 0x81 */  "&uuml;",
+/* 0x82 */  "&eacute;",
+/* 0x83 */  "&acirc;",
+/* 0x84 */  "&auml;",
+/* 0x85 */  "&agrave;",
+/* 0x86 */  "&aring;",
+/* 0x87 */  "&ccedil;",
+/* 0x88 */  "&ecirc;",
+/* 0x89 */  "&euml;",
+/* 0x8a */  "&egrave;",
+/* 0x8b */  "&iuml;",
+/* 0x8c */  "&icirc;",
+/* 0x8d */  "&igrave;",
+/* 0x8e */  "&auml;",
+/* 0x8f */  "&aring;",
+/* 0x90 */  "&eacute;",
+/* 0x91 */  "&aelig;",
+/* 0x92 */  "&aelig;",
+/* 0x93 */  "&ocirc;",
+/* 0x94 */  "&ouml;",
+/* 0x95 */  "&ograve;",
+/* 0x96 */  "&ucirc;",
+/* 0x97 */  "&ugrave;",
+/* 0x98 */  "&yuml;",
+/* 0x99 */  "&ouml;",
+/* 0x9a */  "&uuml;",
+/* 0x9b */  "&oslash;",
+/* 0x9c */  "&pound;",
+/* 0x9d */  "&oslash;",
+/* 0x9e */  "&times;",
+/* 0x9f */  "&#402;", /* small f with hook */
+/* 0xa0 */  "&aacute;",
+/* 0xa1 */  "&iacute;",
+/* 0xa2 */  "&oacute;",
+/* 0xa3 */  "&uacute;",
+/* 0xa4 */  "&ntilde;",
+/* 0xa5 */  "&ntilde;",
+/* 0xa6 */  "&ordf;",
+/* 0xa7 */  "&frac14;",
+/* 0xa8 */  "&iquest;",
+/* 0xa9 */  "&reg;",
+/* 0xaa */  "&not;",
+/* 0xab */  "&frac12;",
+/* 0xac */  "&raquo;",
+/* 0xad */  "&iexcl;",
+/* 0xae */  "&laquo;",
+/* 0xaf */  "&ordm;",
+/* 0xb0 */  "&#9617;", /* light shade */
+/* 0xb1 */  "&#9618;", /* med. shade */
+/* 0xb2 */  "&#9619;", /* dark shade */
+/* 0xb3 */  "&#9474;", /* box-draw light vert. */
+/* 0xb4 */  "&#9508;", /* box-draw light vert. + lt. */
+/* 0xb5 */  "&aacute;",
+/* 0xb6 */  "&acirc;",
+/* 0xb7 */  "&agrave;",
+/* 0xb8 */  "&copy;",
+/* 0xb9 */  "&#9571;", /* box-draw dbl. vert. + lt. */
+/* 0xba */  "&#9553;", /* box-draw dbl. vert. */
+/* 0xbb */  "&#9559;", /* box-draw dbl. dn. + lt. */
+/* 0xbc */  "&#9565;", /* box-draw dbl. up + lt. */
+/* 0xbd */  "&cent;",
+/* 0xbe */  "&yen;",
+/* 0xbf */  "&#9488;", /* box-draw light dn. + lt. */
+/* 0xc0 */  "&#9492;", /* box-draw light up + rt. */
+/* 0xc1 */  "&#9524;", /* box-draw light up + horiz. */
+/* 0xc2 */  "&#9516;", /* box-draw light dn. + horiz. */
+/* 0xc3 */  "&#9500;", /* box-draw light vert. + rt. */
+/* 0xc4 */  "&#9472;", /* box-draw light horiz. */
+/* 0xc5 */  "&#9532;", /* box-draw light vert. + horiz. */
+/* 0xc6 */  "&atilde;",
+/* 0xc7 */  "&atilde;",
+/* 0xc8 */  "&#9562;", /* box-draw dbl. up + rt. */
+/* 0xc9 */  "&#9556;", /* box-draw dbl. dn. + rt. */
+/* 0xca */  "&#9577;", /* box-draw dbl. up + horiz. */
+/* 0xcb */  "&#9574;", /* box-draw dbl. dn. + horiz. */
+/* 0xcc */  "&#9568;", /* box-draw dbl. vert. + rt. */
+/* 0xcd */  "&#9552;", /* box-draw dbl. horiz. */
+/* 0xce */  "&#9580;", /* box-draw dbl. vert. + horiz. */
+/* 0xcf */  "&curren;",
+/* 0xd0 */  "&eth;",
+/* 0xd1 */  "&eth;",
+/* 0xd2 */  "&ecirc;",
+/* 0xd3 */  "&euml;",
+/* 0xd4 */  "&egrave;",
+/* 0xd5 */  "&#305;", /* small dotless i */
+/* 0xd6 */  "&iacute;",
+/* 0xd7 */  "&icirc;",
+/* 0xd8 */  "&iuml;",
+/* 0xd9 */  "&#9496;", /* box-draw light up + lt. */
+/* 0xda */  "&#9484;", /* box-draw light dn. + rt. */
+/* 0xdb */  "&#9608;", /* full-block */
+/* 0xdc */  "&#9604;", /* lower 1/2 block */
+/* 0xdd */  "&brvbar;",
+/* 0xde */  "&igrave;",
+/* 0xdf */  "&#9600;", /* upper 1/2 block */
+/* 0xe0 */  "&oacute;",
+/* above here not done */
 /* 0xe1 */  "&alpha;",
 /* 0xe2 */  "&beta;",
 /* 0xe3 */  "&gamma;",
@@ -997,13 +1000,13 @@ static char *Greek[] = /* Times New Roman Greek */
 /* 0xf6 */  "&phi;",
 /* 0xf7 */  "&chi;",
 /* 0xf8 */  "&psi;",
-/* 0xf9 */  "&omega;",
-/* 0xfa */  "&#970;", /* iotauml */
-/* 0xfb */  "&#971;", /* upsilonuml */
-/* 0xfc */  "&#972;", /* omicronacute */
-/* 0xfd */  "&#973;", /* nuacute */
-/* 0xfe */  "&#974;", /* omegaacute */
-/* 0xff */  "&#63739;",
+/* 0xf9 */  "&omiga;",
+/* 0xfa */  "&iotauml;",
+/* 0xfb */  "&nuuml;",
+/* 0xfc */  "&omicronacute;",
+/* 0xfd */  "&nuacute;",
+/* 0xfe */  "&omegaacute;", /* black square */
+/* 0xff */  "&nbsp;",
 };
 #endif
 
@@ -1022,7 +1025,7 @@ char *
 html_unisymbol_print (unsigned short c)
 {
 	char r[8];
-	snprintf(r, 8, "&#%04d;", c);
+	snprintf(r, 9, "&#%04d;", c);
 	return my_strdup(r);
 }
 
