@@ -4,7 +4,7 @@
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2 of the License, or
+   the Free Software Foundation; either version 3 of the License, or
    (at your option) any later version.
 
    This program is distributed in the hope that it will be useful, 
@@ -41,7 +41,9 @@
  * 25 Sep 04, st001906@hrz1.hrz.tu-darmstadt.de: added stdlib.h for djgpp
  * 29 Mar 05, daved@physiol.usyd.edu.au: changes requested by ZT Smith
  * 06 Jan 06, marcossamaral@terra.com.br: includes verbose mode 
- * 24 Feb 06, daved@physiol.usyd.edu.au: avoid buffer overun in path2
+ * 16 Dec 07, daved@physiol.usyd.edu.au: updated to GPL v3
+ * 17 Dec 07, daved@physiol.usyd.edu.au: support for --noremap from
+ *		David Santinoli
  *--------------------------------------------------------------------*/
 
 #ifdef HAVE_CONFIG_H
@@ -73,9 +75,6 @@
 #include "text.h"
 #include "vt.h"
 #include "latex.h"
-#if 1 /* daved 0.20.3 */
-#include <sys/param.h>
-#endif
 
 
 
@@ -90,6 +89,7 @@ int inline_mode; /* TRUE => Output HTML without HTML/BODY/HEAD -- This is
 					buggy. I've seen it output pages of </font> tags. */
 /* marcossamaral - 0.19.9 */
 int verbose_mode;  /* TRUE => Output additional informations about unrtf */
+int no_remap_mode; /* don't remap codepoints */
 
 
 OutputPersonality *op;
@@ -115,7 +115,7 @@ main (int argc, char **argv)
 	int i;
 	int output_format = OP_HTML;
 
-	nopict_mode = debug_mode = dump_mode = inline_mode = FALSE;
+	nopict_mode = debug_mode = dump_mode = inline_mode = no_remap_mode = FALSE;
 
 	/* Handle arguments */
 	if (argc < 2 || argc > 8) usage();
@@ -126,6 +126,7 @@ main (int argc, char **argv)
 		else if (!strcmp("--debug", argv[i])) debug_mode = TRUE;
 		else if (!strcmp("--verbose", argv[i])) verbose_mode = TRUE;
 		else if (!strcmp("--simple", argv[i])) simple_mode = TRUE;
+		else if (!strcmp("--noremap", argv[i])) no_remap_mode = TRUE;
 		else if (!strcmp("--html", argv[i])) output_format = OP_HTML;
 		else if (!strcmp("--text", argv[i])) output_format = OP_TEXT;
 		else if (!strcmp("--vt", argv[i])) output_format = OP_VT;
@@ -199,11 +200,7 @@ main (int argc, char **argv)
 	/* Open file for reading. Append ".rtf" to file name if not supplied. */
 	f = fopen(path, "r");
 	if (!f) {
-#if 1 /* daved 0.20.3 */
-		char path2[MAXPATHLEN+5];
-#else
 		char path2[200];
-#endif
 		strcpy(path2, path);
 		strcat(path2, ".rtf");
 		f = fopen(path2, "r");
