@@ -33,6 +33,9 @@
  * 25 Sep 04, st001906@hrz1.hrz.tu-darmstadt.de: added stdlib.h for djgpp
  * 29 Mar 05, daved@physiol.usyd.edu.au: changes requested by ZT Smith
  * 06 Jan 06, marcossamaral@terra.com.br: changes in STDOUT   
+ * 16 Dec 07, daved@physiol.usyd.edu.au: updated to GPL v3
+ * 17 Dec 07, daved@physiol.usyd.edu.au: added support for --noremap from
+ *		David Santinoli
  *--------------------------------------------------------------------*/
 
 
@@ -118,9 +121,20 @@ op_translate_char (OutputPersonality *op, int charset, CodepageInfo *codepage, i
 {
 	short start;
 	char *result=NULL;
+#if 1	/* daved - 0.20.5 */
+	static char output_buffer[2]={ 0, 0 };
+#endif
 
 	CHECK_PARAM_NOT_NULL(op);
 
+#if 1	/* daved - 0.20.5 */
+	if (no_remap_mode == TRUE && ch < 256)
+	{
+		output_buffer[0]=ch;
+		result=output_buffer;
+	}
+	else
+#endif
 #if 1 /* daved - 0.19.6 */
 	/* if we are seeking a character from a symbol font we can
 	   be below 0x80
